import 'package:meta/meta.dart';

@immutable
abstract class CustomPageState {}

/// 初始化
class CustomPageInitialState extends CustomPageState {}

/// 数据加载成功
class CustomPageLoadedState extends CustomPageState {
  List<Map<String, dynamic>> model;
  CustomPageLoadedState({this.model});
}

/// 刷新成功
class CustomPageRefreshSuccessState extends CustomPageState{}

/// 刷新失败
class CustomPageRefreshErrorState extends CustomPageState{}

/// 初始化失败
class CustomPageInitErrorState extends CustomPageState {}

/// 数据加载失败
class CustomPageErrorState extends CustomPageState {}
